@@ -256,6 +256,8 @@ class TestGitHubDynamicDependency:
             namespace="bar", version="2.0"
         )
 
+        root_repo = PackageNamespaceVersionDependency(namespace="bar", version="2.0")
+
         assert gh.flatten(project_config) == [
             GitHubDynamicDependency(
                 github="https://github.com/SFDO-Tooling/DependencyRepo",
@@ -266,20 +268,23 @@ class TestGitHubDynamicDependency:
                 subfolder="unpackaged/pre/first",
                 unmanaged=True,
                 ref="aaaaa",
+                package_dependency=root_repo,
             ),
             UnmanagedGitHubRefDependency(
                 github="https://github.com/SFDO-Tooling/RootRepo",
                 subfolder="unpackaged/pre/second",
                 unmanaged=True,
                 ref="aaaaa",
+                package_dependency=root_repo,
             ),
-            PackageNamespaceVersionDependency(namespace="bar", version="2.0"),
+            root_repo,
             UnmanagedGitHubRefDependency(
                 github="https://github.com/SFDO-Tooling/RootRepo",
                 subfolder="unpackaged/post/first",
                 unmanaged=False,
                 ref="aaaaa",
                 namespace_inject="bar",
+                package_dependency=root_repo,
             ),
         ]
 
@@ -295,6 +300,8 @@ class TestGitHubDynamicDependency:
             namespace="bar", version="2.0"
         )
 
+        root_repo = PackageNamespaceVersionDependency(namespace="bar", version="2.0")
+
         assert gh.flatten(project_config) == [
             GitHubDynamicDependency(
                 github="https://github.com/SFDO-Tooling/DependencyRepo",
@@ -305,14 +312,16 @@ class TestGitHubDynamicDependency:
                 subfolder="unpackaged/pre/second",
                 unmanaged=True,
                 ref="aaaaa",
+                package_dependency=root_repo,
             ),
-            PackageNamespaceVersionDependency(namespace="bar", version="2.0"),
+            root_repo,
             UnmanagedGitHubRefDependency(
                 github="https://github.com/SFDO-Tooling/RootRepo",
                 subfolder="unpackaged/post/first",
                 unmanaged=False,
                 ref="aaaaa",
                 namespace_inject="bar",
+                package_dependency=root_repo,
             ),
         ]
 
@@ -1018,6 +1027,7 @@ class TestUnmanagedVcsDependencyFlow:
         # Setup flow config mock
         mock_flow_config = mock.Mock()
         mock_project_config.get_flow.return_value = mock_flow_config
+        mock_project_config.list_tasks.return_value = []
 
         # Setup coordinator mock
         mock_coordinator_instance = mock.Mock()
@@ -1076,11 +1086,7 @@ class TestUnmanagedVcsDependencyFlow:
         assert args[0] == mock_project_config
         assert args[1] == mock_flow_config
         assert kwargs["name"] == "install_deps"
-        assert kwargs["options"] == {
-            "unmanaged": True,  # _get_unmanaged should return True for empty installed_packages
-            "namespace_inject": "test_ns",
-            "namespace_strip": "old_ns",
-        }
+        assert kwargs["options"] == {}
         assert kwargs["skip"] is None
         assert isinstance(kwargs["callbacks"], type(flow_dep.callback_class()))
 
@@ -1089,14 +1095,11 @@ class TestUnmanagedVcsDependencyFlow:
 
         # Verify logging
         assert (
-            mock_context.logger.info.call_count == 3
+            mock_context.logger.info.call_count == 2
         )  # Initial log, fetching log, final log
         mock_context.logger.info.assert_any_call(
             "Deploying dependency Flow from https://github.com/test/repo Flow: install_deps @abc123"
         )
-        mock_context.logger.info.assert_any_call(
-            f"Fetching from {mock_vcs_source_instance}"
-        )
         mock_context.logger.info.assert_any_call("Ran install_deps in 5.2s")
 
         # Verify datetime and format_duration calls
